@@ -4,11 +4,11 @@ import errno
 import logging
 import os
 import threading
+import typing
 from contextlib import contextmanager
 
-import appdirs
+import platformdirs
 import pytz
-import six
 
 # The sqlite3 is not available on Google App Engine so we handle the
 # ImportError here and set the sqlite3 var to None.
@@ -16,23 +16,61 @@ import six
 try:
     import sqlite3
 except ImportError:
-    sqlite3 = None
+    sqlite3 = None  # type: ignore
 
 logger = logging.getLogger(__name__)
 
 
-class Base(object):
+class Base:
+    """Base class for caching backends."""
 
     def add(self, url, content):
-        raise NotImplemented()
+        raise NotImplementedError()
 
     def get(self, url):
-        raise NotImplemented()
+        raise NotImplementedError()
+
+
+class VersionedCacheBase(Base):
+    """Versioned base class for caching backends.
+    Note when subclassing a version class attribute must be provided.
+    """
+
+    def _encode_data(self, data):
+        """Helper function for encoding cacheable content as base64.
+        :param data: Content to be encoded.
+        :rtype: bytes
+        """
+        data = base64.b64encode(data)
+        return self._version_string + data
+
+    def _decode_data(self, data):
+        """Helper function for decoding base64 cached content.
+        :param data: Content to be decoded.
+        :rtype: bytes
+        """
+        if data.startswith(self._version_string):
+            return base64.b64decode(data[len(self._version_string) :])
+
+    @property
+    def _version_string(self):
+        """Expose the version prefix to be used in content serialization.
+        :rtype: bytes
+        """
+        assert (
+            getattr(self, "_version", None) is not None
+        ), "A version must be provided in order to use the VersionedCacheBase backend."
+        prefix = u"$ZEEP:%s$" % self._version
+        return bytes(prefix.encode("ascii"))
 
 
 class InMemoryCache(Base):
     """Simple in-memory caching using dict lookup with support for timeouts"""
-    _cache = {}  # global cache, thread-safe by default
+
+    #: global cache, thread-safe by default
+    _cache = (
+        {}
+    )  # type: typing.Dict[str, typing.Tuple[datetime.datetime, typing.Union[bytes, str]]]
 
     def __init__(self, timeout=3600):
         self._timeout = timeout
@@ -41,7 +79,8 @@ class InMemoryCache(Base):
         logger.debug("Caching contents of %s", url)
         if not isinstance(content, (str, bytes)):
             raise TypeError(
-                "a bytes-like object is required, not {}".format(type(content).__name__))
+                "a bytes-like object is required, not {}".format(type(content).__name__)
+            )
         self._cache[url] = (datetime.datetime.utcnow(), content)
 
     def get(self, url):
@@ -57,9 +96,10 @@ class InMemoryCache(Base):
         return None
 
 
-class SqliteCache(Base):
-    """Cache contents via an sqlite database on the filesystem"""
-    _version = '1'
+class SqliteCache(VersionedCacheBase):
+    """Cache contents via a sqlite database on the filesystem."""
+
+    _version = "1"
 
     def __init__(self, path=None, timeout=3600):
 
@@ -67,10 +107,11 @@ class SqliteCache(Base):
             raise RuntimeError("sqlite3 module is required for the SqliteCache")
 
         # No way we can support this when we want to achieve thread safety
-        if path == ':memory:':
+        if path == ":memory:":
             raise ValueError(
-                "The SqliteCache doesn't support :memory: since it is not " +
-                "thread-safe. Please use zeep.cache.InMemoryCache()")
+                "The SqliteCache doesn't support :memory: since it is not "
+                + "thread-safe. Please use zeep.cache.InMemoryCache()"
+            )
 
         self._lock = threading.RLock()
         self._timeout = timeout
@@ -83,14 +124,16 @@ class SqliteCache(Base):
                 """
                     CREATE TABLE IF NOT EXISTS request
                     (created timestamp, url text, content text)
-                """)
+                """
+            )
             conn.commit()
 
     @contextmanager
     def db_connection(self):
         with self._lock:
             connection = sqlite3.connect(
-                self._db_path, detect_types=sqlite3.PARSE_DECLTYPES)
+                self._db_path, detect_types=sqlite3.PARSE_DECLTYPES
+            )
             yield connection
             connection.close()
 
@@ -103,14 +146,14 @@ class SqliteCache(Base):
             cursor.execute("DELETE FROM request WHERE url = ?", (url,))
             cursor.execute(
                 "INSERT INTO request (created, url, content) VALUES (?, ?, ?)",
-                (datetime.datetime.utcnow(), url, data))
+                (datetime.datetime.utcnow(), url, data),
+            )
             conn.commit()
 
     def get(self, url):
         with self.db_connection() as conn:
             cursor = conn.cursor()
-            cursor.execute(
-                "SELECT created, content FROM request WHERE url=?", (url, ))
+            cursor.execute("SELECT created, content FROM request WHERE url=?", (url,))
             rows = cursor.fetchall()
 
         if rows:
@@ -120,23 +163,6 @@ class SqliteCache(Base):
                 return self._decode_data(data)
         logger.debug("Cache MISS for %s", url)
 
-    def _encode_data(self, data):
-        data = base64.b64encode(data)
-        if six.PY2:
-            return buffer(self._version_string + data)  # noqa
-        return self._version_string + data
-
-    def _decode_data(self, data):
-        if six.PY2:
-            data = str(data)
-        if data.startswith(self._version_string):
-            return base64.b64decode(data[len(self._version_string):])
-
-    @property
-    def _version_string(self):
-        prefix = u'$ZEEP:%s$' % self._version
-        return bytes(prefix.encode('ascii'))
-
 
 def _is_expired(value, timeout):
     """Return boolean if the value is expired"""
@@ -150,7 +176,7 @@ def _is_expired(value, timeout):
 
 
 def _get_default_cache_path():
-    path = appdirs.user_cache_dir('zeep', False)
+    path = platformdirs.user_cache_dir("zeep", False)
     try:
         os.makedirs(path)
     except OSError as exc:
@@ -158,4 +184,4 @@ def _get_default_cache_path():
             pass
         else:
             raise
-    return os.path.join(path, 'cache.db')
+    return os.path.join(path, "cache.db")
