@@ -15,17 +15,21 @@
     This module defines the definitions which occur within a WSDL document,
 
 """
+import typing
 import warnings
 from collections import OrderedDict, namedtuple
 
-from six import python_2_unicode_compatible
+from lxml import etree
 
 from zeep.exceptions import IncompleteOperation
 
-MessagePart = namedtuple('MessagePart', ['element', 'type'])
+if typing.TYPE_CHECKING:
+    from zeep.wsdl.wsdl import Definition
+
+MessagePart = namedtuple("MessagePart", ["element", "type"])
 
 
-class AbstractMessage(object):
+class AbstractMessage:
     """Messages consist of one or more logical parts.
 
     Each part is associated with a type from some type system using a
@@ -37,12 +41,13 @@ class AbstractMessage(object):
         - type: Refers to an XSD simpleType or complexType using a QName.
 
     """
+
     def __init__(self, name):
         self.name = name
         self.parts = OrderedDict()
 
     def __repr__(self):
-        return '<%s(name=%r)>' % (self.__class__.__name__, self.name.text)
+        return "<%s(name=%r)>" % (self.__class__.__name__, self.name.text)
 
     def resolve(self, definitions):
         pass
@@ -51,11 +56,18 @@ class AbstractMessage(object):
         self.parts[name] = element
 
 
-class AbstractOperation(object):
+class AbstractOperation:
     """Abstract operations are defined in the wsdl's portType elements."""
 
-    def __init__(self, name, input_message=None, output_message=None,
-                 fault_messages=None, parameter_order=None):
+    def __init__(
+        self,
+        name,
+        input_message=None,
+        output_message=None,
+        fault_messages=None,
+        parameter_order=None,
+        wsa_action=None,
+    ):
         """Initialize the abstract operation.
 
         :param name: The name of the operation
@@ -73,23 +85,24 @@ class AbstractOperation(object):
         self.output_message = output_message
         self.fault_messages = fault_messages
         self.parameter_order = parameter_order
+        self.wsa_action = wsa_action
 
 
-class PortType(object):
-    def __init__(self, name, operations):
+class PortType:
+    def __init__(
+        self, name: etree.QName, operations: typing.Dict[str, AbstractOperation]
+    ):
         self.name = name
         self.operations = operations
 
     def __repr__(self):
-        return '<%s(name=%r)>' % (
-            self.__class__.__name__, self.name.text)
+        return "<%s(name=%r)>" % (self.__class__.__name__, self.name.text)
 
     def resolve(self, definitions):
         pass
 
 
-@python_2_unicode_compatible
-class Binding(object):
+class Binding:
     """Base class for the various bindings (SoapBinding / HttpBinding)
 
     .. raw:: ascii
@@ -103,6 +116,7 @@ class Binding(object):
                              +-> AbstractMessage
 
     """
+
     def __init__(self, wsdl, name, port_name):
         """Binding
 
@@ -120,8 +134,8 @@ class Binding(object):
         self.wsdl = wsdl
         self._operations = {}
 
-    def resolve(self, definitions):
-        self.port_type = definitions.get('port_types', self.port_name.text)
+    def resolve(self, definitions: "Definition") -> None:
+        self.port_type = definitions.get("port_types", self.port_name.text)
 
         for name, operation in list(self._operations.items()):
             try:
@@ -135,11 +149,17 @@ class Binding(object):
         self._operations[operation.name] = operation
 
     def __str__(self):
-        return '%s: %s' % (self.__class__.__name__, self.name.text)
+        return "%s: %s" % (self.__class__.__name__, self.name.text)
 
     def __repr__(self):
-        return '<%s(name=%r, port_type=%r)>' % (
-            self.__class__.__name__, self.name.text, self.port_type)
+        return "<%s(name=%r, port_type=%r)>" % (
+            self.__class__.__name__,
+            self.name.text,
+            self.port_type,
+        )
+
+    def all(self):
+        return self._operations
 
     def get(self, key):
         try:
@@ -156,13 +176,13 @@ class Binding(object):
         raise NotImplementedError()
 
 
-@python_2_unicode_compatible
-class Operation(object):
+class Operation:
     """Concrete operation
 
     Contains references to the concrete messages
 
     """
+
     def __init__(self, name, binding):
         self.name = name
         self.binding = binding
@@ -177,23 +197,28 @@ class Operation(object):
             self.abstract = self.binding.port_type.operations[self.name]
         except KeyError:
             raise IncompleteOperation(
-                "The wsdl:operation %r was not found in the wsdl:portType %r" % (
-                    self.name, self.binding.port_type.name.text))
+                "The wsdl:operation %r was not found in the wsdl:portType %r"
+                % (self.name, self.binding.port_type.name.text)
+            )
 
     def __repr__(self):
-        return '<%s(name=%r, style=%r)>' % (
-            self.__class__.__name__, self.name, self.style)
+        return "<%s(name=%r, style=%r)>" % (
+            self.__class__.__name__,
+            self.name,
+            self.style,
+        )
 
     def __str__(self):
         if not self.input:
-            return u'%s(missing input message)' % (self.name)
+            return u"%s(missing input message)" % (self.name)
 
-        retval = u'%s(%s)' % (self.name, self.input.signature())
+        retval = u"%s(%s)" % (self.name, self.input.signature())
         if self.output:
-            retval += u' -> %s' % (self.output.signature(as_output=True))
+            retval += u" -> %s" % (self.output.signature(as_output=True))
         return retval
 
     def create(self, *args, **kwargs):
+        assert self.input is not None
         return self.input.serialize(*args, **kwargs)
 
     def process_reply(self, envelope):
@@ -222,30 +247,33 @@ class Operation(object):
         raise NotImplementedError()
 
 
-@python_2_unicode_compatible
-class Port(object):
+class Port:
     """Specifies an address for a binding, thus defining a single communication
     endpoint.
 
     """
+
+    if typing.TYPE_CHECKING:
+        _resolve_context = None  # type: typing.Optional[typing.Dict[str, typing.Any]]
+
     def __init__(self, name, binding_name, xmlelement):
         self.name = name
-        self._resolve_context = {
-            'binding_name': binding_name,
-            'xmlelement': xmlelement,
-        }
+        self._resolve_context = {"binding_name": binding_name, "xmlelement": xmlelement}
 
         # Set during resolve()
         self.binding = None
-        self.binding_options = None
+        self.binding_options = {}
 
     def __repr__(self):
-        return '<%s(name=%r, binding=%r, %r)>' % (
-            self.__class__.__name__, self.name, self.binding,
-            self.binding_options)
+        return "<%s(name=%r, binding=%r, %r)>" % (
+            self.__class__.__name__,
+            self.name,
+            self.binding,
+            self.binding_options,
+        )
 
     def __str__(self):
-        return u'Port: %s (%s)' % (self.name, self.binding)
+        return u"Port: %s (%s)" % (self.name, self.binding)
 
     def resolve(self, definitions):
         if self._resolve_context is None:
@@ -253,38 +281,40 @@ class Port(object):
 
         try:
             self.binding = definitions.get(
-                'bindings', self._resolve_context['binding_name'].text)
+                "bindings", self._resolve_context["binding_name"].text
+            )
         except IndexError:
             return False
 
-        if definitions.location:
-            force_https = definitions.location.startswith('https')
+        if definitions.location and self.binding.wsdl.settings.force_https:
+            force_https = definitions.location.startswith("https")
         else:
             force_https = False
 
         self.binding_options = self.binding.process_service_port(
-            self._resolve_context['xmlelement'],
-            force_https)
+            self._resolve_context["xmlelement"], force_https
+        )
         self._resolve_context = None
         return True
 
 
-@python_2_unicode_compatible
-class Service(object):
-    """Used to aggregate a set of related ports.
+class Service:
+    """Used to aggregate a set of related ports."""
 
-    """
     def __init__(self, name):
         self.ports = OrderedDict()
         self.name = name
         self._is_resolved = False
 
     def __str__(self):
-        return u'Service: %s' % self.name
+        return u"Service: %s" % self.name
 
     def __repr__(self):
-        return '<%s(name=%r, ports=%r)>' % (
-            self.__class__.__name__, self.name, self.ports)
+        return "<%s(name=%r, ports=%r)>" % (
+            self.__class__.__name__,
+            self.name,
+            self.ports,
+        )
 
     def resolve(self, definitions):
         if self._is_resolved:
@@ -302,5 +332,5 @@ class Service(object):
 
         self._is_resolved = True
 
-    def add_port(self, port):
+    def add_port(self, port: Port) -> None:
         self.ports[port.name] = port
